@@ -193,7 +193,8 @@ def _instrument_class(cls: type,
     if cls.__init__ is not object.__init__:
         # noinspection PyTypeChecker
         cls.__init__ = instrument_decorate(cls.__init__, func_name=f'{class_name}.__init__')
-    # todo: also wrap __post_init__
+    if hasattr(cls, '__post_init__'):
+        cls.__post_init__ = instrument_decorate(cls.__post_init__, func_name=f'{class_name}.__post_init__')
 
     # also wrap the call method, if it exists
     if not isinstance(cls.__call__, type(object.__call__)):
